@@ -209,7 +209,7 @@ class MPLogger(PyThread):
         while True:
             msg = self.Queue.get()
             who, t = msg[:2]
-            parts = msg[2:]
+            parts = [str(p) for p in msg[2:]]
             t = datetime.datetime.fromtimestamp(t)
             process_timestamp = t.strftime("%m/%d/%Y %H:%M:%S") + ".%03d" % (t.microsecond//1000)
             self.Logger.log(who, "%s: %s" % (process_timestamp, " ".join(parts)))
@@ -218,11 +218,21 @@ class MPLogger(PyThread):
         #
         # subprocess side
         #
-        if self.Logger is not None:
-            self.Queue.put((who, time.time())+parts)
+        parts = tuple(str(p) for p in parts)
+        self.Queue.put((who, time.time())+parts)
             
-    debug = log
+    def debug(self, who, *parts):
+        #
+        # subprocess side
+        #
+        if self.Debug:
+            self.log(f"{who} [DEBUG]", *parts)
 
+    def error(self, who, *parts):
+        #
+        # subprocess side
+        #
+        self.log(f"{who} [ERROR]", *parts)
 
 class MultiServerSubprocess(Process):
     
@@ -360,9 +370,9 @@ class MultiServerSubprocess(Process):
             
 class MPMultiServer(PyThread, Logged):
             
-    def __init__(self, config_file, logger=None):
+    def __init__(self, config_file, logger=None, debug=False):
         PyThread.__init__(self)
-        Logged.__init__(self, "[Multiserver]", logger, debug=True)
+        Logged.__init__(self, "[Multiserver]", logger, debug=debug)
         self.ConfigFile = config_file
         self.Server = None
         self.Port = None
@@ -372,8 +382,9 @@ class MPMultiServer(PyThread, Logged):
         self.Stop = False
         self.MPLogger = None
         if logger is not None:
-            self.MPLogger = MPLogger(logger)
+            self.MPLogger = MPLogger(logger, debug=debug)
             self.MPLogger.start()
+        self.Debug = debug
         self.reconfigure()
 
     @synchronized
@@ -400,18 +411,18 @@ class MPMultiServer(PyThread, Logged):
                 p = MultiServerSubprocess(self.Port, self.Sock, self.ConfigFile, logger=self.MPLogger)
                 p.start()
                 self.Subprocesses.append(p)
-                self.log("started new subprocess")
+                #self.log("started new subprocess")
         elif new_nprocesses < len(self.Subprocesses):
             while new_nprocesses < len(self.Subprocesses):
                 p = self.Subprocesses.pop()
                 p.stop()
-                self.log("stopped a subprocess")
+                #self.log("stopped a subprocess")
             for p in self.Subprocesses:
                 p.request_reconfigure()
         else:
             for p in self.Subprocesses:
                 p.request_reconfigure()
-        self.log("subprocesses running now:", len(self.Subprocesses))
+        #self.log("subprocesses running now:", len(self.Subprocesses))
         
     def run(self):
         if setproctitle is not None:
@@ -483,7 +494,7 @@ def main():
             logger = Logger(cfg.get("file", "-"), debug=debug)
     if "pid_file" in config:
         open(config["pid_file"], "w").write(str(os.getpid()))
-    ms = MPMultiServer(config_file, logger)
+    ms = MPMultiServer(config_file, logger, debug)
     signal.signal(signal.SIGHUP, ms.reconfigure)
     #signal.signal(signal.SIGCHLD, ms.child_died)
     signal.signal(signal.SIGINT, ms.killme)
